bayespy.inference.vmp.nodes.gaussian.GaussianDistribution.compute_moments_and_cgf
=================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianDistribution.compute_moments_and_cgf